==> RHmm_1.4.4.tar.gz: RHmm/src/cInParam.h <==
/**************************************************************
 *** RHmm version 1.4.4                                     
 ***                                                         
 *** File: cInParam.h 
 ***                                                         
 *** Author: Ollivier TARAMASCO <Ollivier.Taramasco@imag.fr> 
 *** Author: Sebastian BAUER <sebastian.bauer@charite.de>
 *** Date: 2010/12/09                                     
 ***                                                         
 **************************************************************/

#ifndef _CINPARAM_H_
#define _CINPARAM_H_
#pragma once

#include "Hmm.h"


class cInParam
{       public :
                distrDefinitionEnum     mDistrType              ; // Type de loi de proba
                uint                            mNClass                 ; // Nombre de classes
                uint                            mDimObs                 ; // Dimension des observations
                uint                            mNMixt                  ; // Nombre de lois mlanges
                uint                            mNProba                 ; // Nombre de proba discrtes
                uint                            mNSample                ; // Nombre d'chantillons
                cOTVector*                      mY                              ; // Tableau mNSample x mT[i] des observations
        public :
                cInParam(uint theNSample, uint theDimObs, cOTVector* theY, distrDefinitionEnum theDistrType=eNormalDistr, uint theNClass=2, uint theNMixt=0, uint theNProba=0) ;
                virtual ~cInParam() ;
                cInParam & operator =(const cInParam &theSrc) ;
                virtual void Print(void) ;
} ;
#endif //_CINPARAM_H_

==> RHmm_1.5.0.tar.gz: RHmm/src/cInParam.h <==
/**************************************************************
 *** RHmm version 1.5.0
 ***                                                         
 *** File: cInParam.h 
 ***                                                         
 *** Author: Ollivier TARAMASCO <Ollivier.Taramasco@imag.fr> 
 *** Author: Sebastian BAUER <sebastian.bauer@charite.de>
 ***                                                         
 **************************************************************/

#ifndef _CINPARAM_H_
#define _CINPARAM_H_
#pragma once

#include "Hmm.h"


class cInParam
{       public :
                distrDefinitionEnum     mDistrType              ; // Type de loi de proba
                uint                            mNClass                 ; // Nombre de classes
                uint                            mDimObs                 ; // Dimension des observations
                uint                            mNMixt                  ; // Nombre de lois mlanges
                uint                            mNProba                 ; // Nombre de proba discrtes
                uint                            mNSample                ; // Nombre d'chantillons
                cDVector*                      mY                              ; // Tableau mNSample x mT[i] des observations
        public :
                cInParam(uint theNSample, uint theDimObs, cDVector* theY, distrDefinitionEnum theDistrType=eNormalDistr, uint theNClass=2, uint theNMixt=0, uint theNProba=0) ;
                virtual ~cInParam() ;
                cInParam & operator =(const cInParam &theSrc) ;
                virtual void Print(void) ;
} ;
#endif //_CINPARAM_H_
